"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.urlFontawesome = exports.litFontawesome = void 0;
const lit_html_1 = require("lit-html");
function litFontawesome(definition, { className, color } = {}) {
    return lit_html_1.svg `
        <svg
            aria-hidden="true"
            focusable="false"
            data-prefix="${definition.prefix}"
            data-icon="${definition.iconName}"
            role="img"
            xmlns="http://www.w3.org/2000/svg"
            viewBox="0 0 ${definition.icon[0]} ${definition.icon[1]}"
            class="${className || ''} ${definition.prefix}_${definition.iconName} fa-${definition.iconName}"
        >
            <g fill="${color || 'currentColor'}">
                ${(Array.isArray(definition.icon[4]) ? definition.icon[4] : [definition.icon[4]]).map((icon) => lit_html_1.svg `<path d="${icon}"></path>`)}
            </g>
        </svg>
    `;
}
exports.litFontawesome = litFontawesome;
function uncachedUrlFontawesome(definition, options) {
    const mount = window.document.createElement('div');
    lit_html_1.render(litFontawesome(definition, options), mount);
    return `data:image/svg+xml;base64,${btoa(mount.innerHTML.replace(/ {4}|<!---->|\n/g, ''))}`;
}
const cachedURL = new Map();
function urlFontawesome(definition, options = {}) {
    let dataUrl;
    const foundDefinition = cachedURL.get(definition);
    let foundClassName;
    if (foundDefinition !== undefined) {
        foundClassName = foundDefinition.get(options.className);
        if (foundClassName !== undefined) {
            const foundColor = foundClassName.get(options.color);
            if (foundColor !== undefined) {
                dataUrl = foundColor;
            }
        }
    }
    if (dataUrl === undefined) {
        dataUrl = uncachedUrlFontawesome(definition, options);
        if (foundDefinition === undefined) {
            cachedURL.set(definition, new Map([[options.className, new Map([[options.color, dataUrl]])]]));
        }
        else if (foundClassName === undefined) {
            foundDefinition.set(options.className, new Map([[options.color, dataUrl]]));
        }
        else {
            foundClassName.set(options.color, dataUrl);
        }
    }
    return dataUrl;
}
exports.urlFontawesome = urlFontawesome;
//# sourceMappingURL=litFontawesome.js.map